==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/nullcheck/NullPointerColorer.h <==
// public class soot.jimple.toolkits.annotation.nullcheck.NullPointerColorer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class c9c8ce42cd5e0441 soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer_H_
#define _JC_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object;
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_refs	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$refs	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$nonrefs	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vmethods	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtable	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtype	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$method$addColorTags$868e380cce11df88(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object *);
extern void _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$method_info$addColorTags$868e380cce11df88;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object *_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$method$v$05cdf877b8598b14(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vmethods {
	void	(*addColorTags$868e380cce11df88)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object *);
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vmethods	soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$refs {
    _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_refs	soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_nonrefs	soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object {
	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtype _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/nullcheck/NullPointerColorer.h <==
// public class soot.jimple.toolkits.annotation.nullcheck.NullPointerColorer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class c9c8ce42cd5e0441 soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer_H_
#define _JC_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object;
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_refs	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$refs	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$nonrefs	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vmethods	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtable	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtype	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$method$addColorTags$868e380cce11df88(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$method_info$addColorTags$868e380cce11df88;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object *_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$method$v$05cdf877b8598b14(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vmethods {
	void	(*addColorTags$868e380cce11df88)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object *) _JC_JCNI_ATTR;
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vmethods	soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$refs {
    _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_refs	soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$sub_nonrefs	soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$object {
	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$vtype _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_nullcheck_NullPointerColorer_H_ */
